@@ -29,6 +29,12 @@
 #include <string.h>
 #include <errno.h>
 
+#define LIBNXML_VERSION_STRING	"0.18.1"
+
+#define LIBNXML_MAJOR_VERSION	0
+#define LIBNXML_MINOR_VERSION	18
+#define LIBNXML_MICRO_VERSION	1
+
 #ifdef  __cplusplus
 extern "C" {
 #endif
@@ -48,6 +54,7 @@ typedef enum
   NXML_OK = 0,			/**< No error */
   NXML_ERR_POSIX,		/**< For the correct error, use errno */
   NXML_ERR_PARSER,		/**< Parser error */
+  NXML_ERR_DOWNLOAD,		/**< Download error */
   NXML_ERR_DATA			/**< The parameters are incorrect */
 } nxml_error_t;
 
@@ -184,6 +191,8 @@ struct __nxml_private_t
   char *user_agent;
   char textindent;
 
+  CURLcode curl_error;
+
   __nxml_entity_t *entities;
 };
 
@@ -671,10 +680,23 @@ nxml_error_t	nxml_get_string		(nxml_data_t *element,
 /**
  * This function returns a static string with the description of error code
  *
+ * \param nxml the pointer to data struct
  * \param err the error code that you need as string
  * \return a string. Don't free this string!
  */
-char *		nxml_strerror		(nxml_error_t err);
+char *		nxml_strerror		(nxml_t * nxml,
+					 nxml_error_t err);
+
+/**
+ * This function returns the CURLcode error if there was a problem about the
+ * downloading procedure:
+ *
+ * \param nxml the pointer to data struct
+ * \param err the error code that you need as string
+ * \return the CURLcode
+ */
+CURLcode	nxml_curl_error		(nxml_t * nxml,
+					 nxml_error_t err);
 
 /**
  * This function return the line of a error of parse.
