@@ -634,7 +634,7 @@ __nxml_parse_doctype (nxml_t * doc, char **buffer, size_t * size,
       size = strlen (value);
 
       while (size > 0 && value && *value)
-	__nxml_parse_entity (doc, &value, &size);
+	__nxml_parse_entity (doc, &value, (size_t *)&size);
     }
 
   return NXML_OK;
